(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     14958,        383]
NotebookOptionsPosition[     12530,        337]
NotebookOutlinePosition[     13139,        360]
CellTagsIndexPosition[     13096,        357]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 3, Section 3.12, Figure 3.27", "Section",ExpressionUUID->"6f53d116-91d6-4e1a-82bb-825237ae2c74"],

Cell[TextData[{
 "We want to express Eq.(3.199) in a form where ",
 StyleBox["H",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", 
    StyleBox["min",
     FontSlant->"Plain"]], TraditionalForm]],ExpressionUUID->
  "e7f8f627-fde5-48e0-9e5f-6d7d638d7265"],
 ")",
 " is a function of (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "1"], TraditionalForm]],ExpressionUUID->
  "5cb4986c-f1ec-4ad5-8312-f80011e96611"],
 "+ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "2"], TraditionalForm]],ExpressionUUID->
  "327d5157-b7eb-46c0-b41c-ee353daa1272"],
 ")/",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", 
    StyleBox["c",
     FontSlant->"Plain"]], TraditionalForm]],ExpressionUUID->
  "957a36a4-c7e7-4b14-b805-1922f0792878"],
 ".  To do this we first take a fixed value for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "180"], TraditionalForm]],ExpressionUUID->
  "f91d3d72-e4da-47a7-9305-75cd60b42b8e"],
 "/",
 StyleBox["a  ",
  FontSlant->"Italic"],
 "(see the text) and define the function ",
 StyleBox["const", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1a870e9c-225b-434f-b24e-fa793d8edab9"],

Cell["const[mass_] := ((3.32*10^(-4))^2 * (3/4) / mass)+1", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"dd8cbfd3-a089-48bf-a820-db4343d96e5b"],

Cell[TextData[{
 "Now define the function ",
 StyleBox["H",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox["\[Theta]", TraditionalForm]],ExpressionUUID->
  "844458d2-107b-48f8-abd7-1fe76991fbed"],
 ") as in Eq.(3.179) making sure we express \[Theta] in degrees."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f0195c3b-cfd1-4893-82a3-8ec0ea22da03"],

Cell["H[\[Theta]_]:=1/Sin[(\[Theta] \[Degree])/2]-2*Cos[\[Theta] \
\[Degree]]-2", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"c8c969c0-4fa9-44bf-8298-c44f5680acc2"],

Cell[TextData[{
 "Set up a table of values of the log of the mass ratio ( =(total mass of \
satellites)/(mass of planet)) and the value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "min"], TraditionalForm]],ExpressionUUID->
  "3596207a-be3c-49df-871f-916cd426f5b7"],
 ".  Here we are solving Eq.(3.199) to find ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "min"], TraditionalForm]],ExpressionUUID->
  "fe7c4b3f-348a-4a5b-b595-444b1fb67a6a"],
 "for a given value of ",
 StyleBox["mass", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cb6cce9a-9dc7-49b9-a9a9-a662707c0b1d"],

Cell["\<\
\[Theta]min =
N[Table[{Log[10,mass],
 \[Theta] /. FindRoot[H[\[Theta]] == const[mass], 
      {\[Theta], -Log[10,mass]}]},
{mass, 10^(-10), 10^(-8), 10^(-10)}]];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"129b8876-1c73-4b84-805e-f86f0616a123"],

Cell["Plot the resulting curve.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1daf2377-0170-4e31-8a68-e596a6aa7bf1"],

Cell[CellGroupData[{

Cell["\<\
p=
ListPlot[\[Theta]min, PlotJoined->True, Frame->True,
 PlotRange->{{-10,-8},{0,10}}]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"50fd64f5-c328-40f0-9d0e-8a35d723d204"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwlVHs81QcUv13P5nVxu1yve35XqdZEy6MXv1NRWcW6rfXyaCP6lJJFeYUk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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-8., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-10, -8}, {0, 10}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8111660649453297`*^9, 3.8111661531871557`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"56892fde-f66b-4fea-8601-64d2599fb38d"]
}, Open  ]],

Cell[TextData[{
 "The observed value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "min"], TraditionalForm]],ExpressionUUID->
  "b56acfd2-266f-4de3-9089-e92cc02cf645"],
 "is 5.64\[Degree]."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"432d37b7-814e-4a8f-aa91-9df09406dadb"],

Cell["\[Theta]minobs=5.64;", "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"50ba3b3b-99a2-46df-8cc8-0f91f9fb1101"],

Cell["\<\
Hence, from Eq.(3.199), the corresponding value of the log of the mass ratio \
is:\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"17940b8d-7b8a-4a08-82f8-e66f3c8b16ff"],

Cell[CellGroupData[{

Cell["\<\
logmassobs = 
Log[10,mass /. FindRoot[
  H[\[Theta]minobs] == const[mass],{mass,10^(-8)}]]\
\>", "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"fbeda68e-72db-46e8-8e08-24be3c9f8c1d"],

Cell[BoxData[
 RowBox[{"-", "8.2683616851465`"}]], "Output",
 CellChangeTimes->{3.811166064984956*^9, 3.8111661532101507`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"992013e5-eb71-4bc3-88f4-437d5b04a40e"]
}, Open  ]],

Cell["Create a graphics object for the observed data point ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4d86b318-ec24-45c5-89f0-7ca2a8619442"],

Cell["\<\
obs=
Graphics[
 {PointSize[0.03],Point[{logmassobs,\[Theta]minobs}]}];\
\>", "Input",
 CellChangeTimes->{3.811166132524959*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"b040d9af-0b25-41dd-8332-2398e623c199"],

Cell["... and add it to the plot.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a27ba854-e015-4c6d-8c23-7d118295a5e9"],

Cell[CellGroupData[{

Cell["Show[p,obs]", "Input",
 CellLabel->"In[8]:=",ExpressionUUID->"dbbe64ba-4fd1-4157-b3c3-2e5d917618c1"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwlVHs81QcUv13P5nVxu1yve35XqdZEy6MXv1NRWcW6rfXyaCP6lJJFeYUk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       "]]}}, {{}, {}}}, 
   {PointSize[0.03], PointBox[{-8.2683616851465, 5.64}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-8., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-10, -8}, {0, 10}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8111660649953527`*^9, 3.811166153217166*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"b927fc3d-a8fb-4e02-a905-b5db3e7de426"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{915, 741},
WindowMargins->{{18, Automatic}, {Automatic, 91}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"105d559f-d89e-4061-8e6d-12453fc8a815"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 110, 0, 67, "Section",ExpressionUUID->"6f53d116-91d6-4e1a-82bb-825237ae2c74"],
Cell[671, 22, 1199, 43, 72, "Text",ExpressionUUID->"1a870e9c-225b-434f-b24e-fa793d8edab9"],
Cell[1873, 67, 178, 2, 30, "Input",ExpressionUUID->"dd8cbfd3-a089-48bf-a820-db4343d96e5b"],
Cell[2054, 71, 392, 12, 53, "Text",ExpressionUUID->"f0195c3b-cfd1-4893-82a3-8ec0ea22da03"],
Cell[2449, 85, 200, 3, 30, "Input",ExpressionUUID->"c8c969c0-4fa9-44bf-8298-c44f5680acc2"],
Cell[2652, 90, 649, 18, 76, "Text",ExpressionUUID->"cb6cce9a-9dc7-49b9-a9a9-a662707c0b1d"],
Cell[3304, 110, 296, 8, 102, "Input",ExpressionUUID->"129b8876-1c73-4b84-805e-f86f0616a123"],
Cell[3603, 120, 151, 3, 53, "Text",ExpressionUUID->"1daf2377-0170-4e31-8a68-e596a6aa7bf1"],
Cell[CellGroupData[{
Cell[3779, 127, 221, 6, 66, "Input",ExpressionUUID->"50fd64f5-c328-40f0-9d0e-8a35d723d204"],
Cell[4003, 135, 3321, 67, 248, "Output",ExpressionUUID->"56892fde-f66b-4fea-8601-64d2599fb38d"]
}, Open  ]],
Cell[7339, 205, 325, 10, 53, "Text",ExpressionUUID->"432d37b7-814e-4a8f-aa91-9df09406dadb"],
Cell[7667, 217, 115, 1, 30, "Input",ExpressionUUID->"50ba3b3b-99a2-46df-8cc8-0f91f9fb1101"],
Cell[7785, 220, 216, 6, 53, "Text",ExpressionUUID->"17940b8d-7b8a-4a08-82f8-e66f3c8b16ff"],
Cell[CellGroupData[{
Cell[8026, 230, 193, 5, 66, "Input",ExpressionUUID->"fbeda68e-72db-46e8-8e08-24be3c9f8c1d"],
Cell[8222, 237, 204, 3, 34, "Output",ExpressionUUID->"992013e5-eb71-4bc3-88f4-437d5b04a40e"]
}, Open  ]],
Cell[8441, 243, 182, 3, 53, "Text",ExpressionUUID->"4d86b318-ec24-45c5-89f0-7ca2a8619442"],
Cell[8626, 248, 215, 6, 66, "Input",ExpressionUUID->"b040d9af-0b25-41dd-8332-2398e623c199"],
Cell[8844, 256, 153, 3, 53, "Text",ExpressionUUID->"a27ba854-e015-4c6d-8c23-7d118295a5e9"],
Cell[CellGroupData[{
Cell[9022, 263, 106, 1, 30, "Input",ExpressionUUID->"dbbe64ba-4fd1-4157-b3c3-2e5d917618c1"],
Cell[9131, 266, 3383, 68, 271, "Output",ExpressionUUID->"b927fc3d-a8fb-4e02-a905-b5db3e7de426"]
}, Open  ]]
}
]
*)

